@@ -1,7 +1,7 @@
 package Device::Cdio::ISO9660::FS;
 require 5.8.6;
 #
-#    $Id: FS.pm,v 1.7 2006/03/03 21:01:43 rocky Exp $
+#    $Id: FS.pm,v 1.8 2006/03/13 03:30:49 rocky Exp $
 #
 #    Copyright (C) 2006 Rocky Bernstein <rocky@cpan.org>
 #
@@ -92,7 +92,7 @@ negative values will not get confused as a named parameter.
 
 =cut
 
-$revision = '$Id: FS.pm,v 1.7 2006/03/03 21:01:43 rocky Exp $';
+$revision = '$Id: FS.pm,v 1.8 2006/03/13 03:30:49 rocky Exp $';
 
 $Device::Cdio::ISO9660::FS::VERSION = $Device::Cdio::VERSION;
 
@@ -247,17 +247,13 @@ sub read_superblock {
 
 =head2 stat
 
-stat(path, translate=0, mode2=0)->\%stat
+stat(path, translate=0)->\%stat
 
 Return file status for path name psz_path. NULL is returned on error.
 
 If translate is 1,  version numbers in the ISO 9660 name are dropped, i.e. ;1
 is removed and if level 1 ISO-9660 names are lowercased.
 
-Mode2 is used only if translate is 1 and is a hack that really should go 
-away in libcdio sometime. If set use mode 2 reading, otherwise use
-mode 1 reading. 
-
 Each item of @iso_stat is a hash reference which contains
 
 =over 4
@@ -292,12 +288,11 @@ if the file has XA attributes; 0 if not
 
 sub stat {
     my($self, @p) = @_;
-    my($path, $translate, $mode2, @args) = 
-	_rearrange(['PATH', 'TRANSLATE', 'MODE2'], @p);
+    my($path, $translate, @args) = 
+	_rearrange(['PATH', 'TRANSLATE'], @p);
     
     return undef if _extra_args(@args);
     $translate = 0 if !defined($translate);
-    $mode2 = 0 if !defined($mode2);
 
     if (!defined($path)) {
       print "*** An CD-ROM or CD-image must be given\n";
@@ -306,8 +301,7 @@ sub stat {
 
     my @values;
     if ($translate) {
-	@values = perliso9660::fs_stat_translate($self->{cd}, $path, 
-						 $mode2); 
+	@values = perliso9660::fs_stat_translate($self->{cd}, $path);
     } else {
 	@values = perliso9660::fs_stat($self->{cd}, $path);
     }
